<?php

/**
 * @file
 * Rules Definitions
 */

/*------------------EVENTS----------------------*/
/**
 * Implements hook_rules_event_info().
 */
function menu_rules_rules_event_info() {
  $events = array();

  $events['menu_rules_menu_link_insert'] = array(
    'label' => t('A menu link was inserted'),
    'variables' => array(
      'menu_link' => array('type' => 'menu', 'label' => t('The menu link that was inserted')),
    ),
    'group' => t('Menu'),
  );
  $events['menu_rules_menu_link_update'] = array(
    'label' => t('A menu link was updated'),
    'variables' => array(
      'menu_link' => array('type' => 'menu', 'label' => t('The menu link that was updated')),
    ),
    'group' => t('Menu'),
  );

  $events['menu_rules_menu_link_delete'] = array(
    'label' => t('A menu link was deleted'),
    'variables' => array(
      'menu_link' => array('type' => 'menu', 'label' => t('The menu link that was deleted')),
    ),
    'group' => t('Menu'),
  );
  $events['menu_rules_menu_link_change'] = array(
    'label' => t('A menu link was changed in some way (inserted/updated/deleted)'),
    'variables' => array(
      'menu_link' => array('type' => 'menu-link', 'label' => t('The menu link that was changed')),
      'op' => array('type' => 'text', 'label' => t('The operation that has been executed on the link (insert/update/delete)')),
    ),
    'group' => t('Menu'),
  );
  return $events;
}
/*------------------CONDITIONS----------------------*/
/**
 * Implements hook_rules_condition_info().
 */
function menu_rules_rules_condition_info() {
  $conditions = array();
  $conditions['menu_rules_node_has_menu_entry'] = array(
    'label' => t('Node has menu entry'),
    'parameter' => array(
      'nid' => array(
        'type' => 'text',
        'label' => t('Nid'),
        'default value' => '[node:nid]',
      ),
    ),
    'group' => t('Menu'),
    'base' => 'menu_rules_node_has_menu_entry',
  );
  return $conditions;
}
/**
 * Callback for condition menu_rules_node_has_menu_entry.
 */
function menu_rules_node_has_menu_entry($nid) {
  $query = db_select('menu_links')->condition('link_path', 'node/' . $nid);
  $num = $query->countQuery()->execute()->fetchField();
  if($num) {
    return TRUE;
  }
  else {
    return FALSE;
  }
}
/*------------------ACTIONS----------------------*/
/**
 * Implements hook_rules_action_info().
 */
function menu_rules_rules_action_info() {
  $actions = array();
  $actions['menu_rules_create_item'] = array(
    'label' => t('Create a menu item for node'),
    'parameter' => array(
      'menu_parent' => array(
        'type' => 'text',
        'label' => t('Menu parent item'),
        'options list' => 'menu_rules_get_menu_parents',
        'default value' => 'main-menu:0',
      ),
      'menu_link_title' => array(
        'type' => 'text',
        'label' => t('Menu link title'),
        'default value' => '[node:title]',
      ),
      'nid' => array(
        'type' => 'text',
        'label' => 'Nid',
        'default value' => '[node:nid]',
      ),
      'language' => array(
        'type' => 'text',
        'label' => 'Language',
        'default value' => '[node:language]',
      ),
    ),
    'group' => t('Menu'),
    'base' => 'menu_rules_create_item',
  );
  $actions['menu_rules_menu_rebuild'] = array(
    'label' => t('Rebuild all menus'),
    'group' => t('Menu'),
    'base' => 'menu_rules_menu_rebuild',
  );
  return $actions;
}
/**
 * Generates option list for action menu_rules_create_item.
 */
function menu_rules_get_menu_parents() {
  $options = menu_parent_options(menu_get_menus(), 0);
  return $options;
}
/**
 * Callback for action menu_rules_create_item.
 */
function menu_rules_create_item($menu_parent, $menu_link_title, $nid, $language) {
  $item = array(
    'link_title' => $menu_link_title,
    'link_path' => 'node/' . $nid,
    'language' => $language,
  );
  list($item['menu_name'], $item['plid']) = explode(':', $menu_parent);
  menu_link_save($item);
}
/**
 * Callback for action menu_rules_menu_rebuild.
 */
function menu_rules_menu_rebuild() {
  static $done;
  // Prevents multiple rebuilds during the same page load.
  if (!$done) {
    $done = TRUE;
    menu_rebuild();
  }
}
